aboutsummaryrefslogtreecommitdiff
path: root/include/conda.h
diff options
context:
space:
mode:
authorJoseph Hunkeler <jhunkeler@users.noreply.github.com>2024-10-07 13:47:17 -0400
committerGitHub <noreply@github.com>2024-10-07 13:47:17 -0400
commitda3ef1951d68485f8d833674c7de2d724a668342 (patch)
treef365a5fdf1e56855fbccf6b1606050b8f29893c5 /include/conda.h
parenta0fcdef5121d5f25ddf5e6e85941ce2a4f3ce7b1 (diff)
parente3be6e430a726a28de4c342e81ce7ac34448de8e (diff)
downloadstasis-da3ef1951d68485f8d833674c7de2d724a668342.tar.gz
Merge pull request #54 from jhunkeler/fix-bare-package-arguments
Fix bare package arguments
Diffstat (limited to 'include/conda.h')
-rw-r--r--include/conda.h13
1 files changed, 8 insertions, 5 deletions
diff --git a/include/conda.h b/include/conda.h
index b5ea926..b26c7a3 100644
--- a/include/conda.h
+++ b/include/conda.h
@@ -186,15 +186,18 @@ int conda_index(const char *path);
/**
* Determine whether a simple index contains a package
* @param index_url a file system path or url pointing to a simple index
* @param name package name (required)
* @param version package version (may be NULL)
* @return not found = 0, found = 1, error = -1
*/
-int pip_index_provides(const char *index_url, const char *name, const char *version);
-
-char *conda_get_active_environment();
+int pip_index_provides(const char *index_url, const char *spec);
+/**
+ * Determine whether conda can find a package in its channel list
+ * @param spec a conda package specification (e.g. `name=1.2.3`)
+ * @return not found = 0, found = 1, error = -1
+ */
int conda_provides(const char *spec);
+char *conda_get_active_environment();
#endif //STASIS_CONDA_H
@@ -186,15 +186,18 @@ int conda_index(const char *path);
* Determine whether a simple index contains a package
* @param index_url a file system path or url pointing to a simple index
- * @param name package name (required)
- * @param version package version (may be NULL)
+ * @param spec a pip package specification (e.g. `name==1.2.3`)
* @return not found = 0, found = 1, error = -1
*/